==> touhoulittlemaid-fabric-1.21.1-0.0.2-neo1.2.2-sources.jar: com/github/tartaricacid/touhoulittlemaid/init/InitDamage.java <==
package com.github.tartaricacid.touhoulittlemaid.init;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.entity.projectile.EntityDanmaku;
import net.minecraft.class_1282;
import net.minecraft.class_1297;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_5321;
import net.minecraft.class_7891;
import net.minecraft.class_7924;
import net.minecraft.class_8107;
import net.minecraft.class_8110;

public final class InitDamage {
    public static final class_5321<class_8110> DANMAKU = class_5321.method_29179(class_7924.field_42534, class_2960.method_60655(TouhouLittleMaid.MOD_ID, "danmaku"));
    public static final class_5321<class_8110> DANMAKU_ENDER_KILLER = class_5321.method_29179(class_7924.field_42534, class_2960.method_60655(TouhouLittleMaid.MOD_ID, "danmaku_ender_killer"));

    public static class_1282 danmakuDamage(class_1297 thrower, EntityDanmaku danmaku) {
        class_2378<class_8110> damageTypes = thrower.field_6002.method_30349().method_30530(class_7924.field_42534);
        if (danmaku.isHurtEnderman()) {
            return new class_1282(damageTypes.method_40290(DANMAKU_ENDER_KILLER), thrower);
        } else {
            return new class_1282(damageTypes.method_40290(DANMAKU), thrower);
        }
    }

    public static void bootstrap(class_7891<class_8110> context) {
        context.method_46838(DANMAKU, new class_8110("danmaku", 0.1f, class_8107.field_42275));
        context.method_46838(DANMAKU_ENDER_KILLER, new class_8110("danmaku_ender_killer", 0.1f, class_8107.field_42275));
    }
}

==> touhoulittlemaid-fabric-1.21.1-0.0.3-neo1.3.6-sources.jar: com/github/tartaricacid/touhoulittlemaid/init/InitDamage.java <==
package com.github.tartaricacid.touhoulittlemaid.init;

import com.github.tartaricacid.touhoulittlemaid.TouhouLittleMaid;
import com.github.tartaricacid.touhoulittlemaid.entity.projectile.EntityDanmaku;
import net.minecraft.class_1282;
import net.minecraft.class_1297;
import net.minecraft.class_2378;
import net.minecraft.class_2960;
import net.minecraft.class_5321;
import net.minecraft.class_7891;
import net.minecraft.class_7924;
import net.minecraft.class_8107;
import net.minecraft.class_8110;

public final class InitDamage {
    public static final class_5321<class_8110> DANMAKU = class_5321.method_29179(class_7924.field_42534, class_2960.method_60655(TouhouLittleMaid.MOD_ID, "danmaku"));
    public static final class_5321<class_8110> DANMAKU_ENDER_KILLER = class_5321.method_29179(class_7924.field_42534, class_2960.method_60655(TouhouLittleMaid.MOD_ID, "danmaku_ender_killer"));

    public static class_1282 danmakuDamage(class_1297 thrower, EntityDanmaku danmaku) {
        class_2378<class_8110> damageTypes = thrower.field_6002.method_30349().method_30530(class_7924.field_42534);
        if (danmaku.isHurtEnderman()) {
            return new class_1282(damageTypes.method_40290(DANMAKU_ENDER_KILLER), danmaku, thrower);
        } else {
            return new class_1282(damageTypes.method_40290(DANMAKU), danmaku, thrower);
        }
    }

    public static void bootstrap(class_7891<class_8110> context) {
        context.method_46838(DANMAKU, new class_8110("danmaku", 0.1f, class_8107.field_42275));
        context.method_46838(DANMAKU_ENDER_KILLER, new class_8110("danmaku_ender_killer", 0.1f, class_8107.field_42275));
    }
}
